package
Version:
v0.0.2
Opens a new window with list of versions in this module.
Published: Dec 19, 2025
License: GPL-3.0
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func New(contentDir, templateDir, staticDir, outputDir, siteTitle string) *Builder
Source Files
¶
Click to show internal directories.
Click to hide internal directories.